package dominio;

import gui.JPTelefono;

public class Telefono {
	protected String numero;
	protected Centralita centralita;
	protected int estado;
	protected JPTelefono gui;
	
	public Telefono(Centralita centralita, int numero) {
		this.centralita=centralita;
		this.numero=""+numero;
		if (this.numero.length()==1) this.numero="0"+this.numero;
		if (this.numero.length()==2) this.numero="0"+this.numero;
		estado=EstadosTelefono.EN_SILENCIO;
	}
	
	public void descolgar() {
		if (estado==EstadosTelefono.EN_SILENCIO) {
			setEstado(EstadosTelefono.EN_ESPERA_DE_LINEA);
			centralita.solicitarLinea(this);
		} else if (estado==EstadosTelefono.TIMBRE_SONANDO) {
			setEstado(EstadosTelefono.DESCOLGADO_RECEPTOR);
			centralita.responder(this);
		}
	}
	
	public void tonoDeMarcar() {
		setEstado(EstadosTelefono.MARCANDO);
	}
	
	public void marcar(int digito) {
		if (this.estado==EstadosTelefono.MARCANDO) {
			centralita.marcar(this, digito);
		} else if (this.estado==EstadosTelefono.RECEPTOR_OCUPADO) {
			if (digito==6) {
				setEstado(EstadosTelefono.RETROLLAMADA_SOLICITADA);
				centralita.solicitarRetrollamada(this);
			} else {
				setEstado(EstadosTelefono.NO_HAY_LINEA);
				centralita.anularRetrollamada(this);
			}
		}
	}
	
	public void tonoDeOcupado() {
		if (estado==EstadosTelefono.EN_ESPERA_DE_LINEA) {
			setEstado(EstadosTelefono.NO_HAY_LINEA);
		} else if (estado==EstadosTelefono.MARCANDO) {
			setEstado(EstadosTelefono.RECEPTOR_OCUPADO);
		} else if (estado==EstadosTelefono.CONVERSANDO) {
			setEstado(EstadosTelefono.LLAMADA_TERMINADA);
		} else if (estado==EstadosTelefono.DESCOLGADO_RECEPTOR) {
			setEstado(EstadosTelefono.LLAMADA_TERMINADA);
		}
	}
	
	public void numeroNoExiste() {
		setEstado(EstadosTelefono.NUMERO_INEXISTENTE);
	}
	
	public void tonoDeLlamada() {
		setEstado(EstadosTelefono.ESPERANDO_RESPUESTA);
	}
	
	public void habilitarConversacionComoEmisor() {
		setEstado(EstadosTelefono.CONVERSANDO);
	}
	
	public void colgar() {
		if (estado==EstadosTelefono.DESCOLGADO_RECEPTOR) {
			centralita.finalizarConversacionReceptor(this);
		} else if (estado==EstadosTelefono.EN_ESPERA_DE_LINEA) { 
			centralita.liberarLineaNoUsada(this);
		} else if (estado==EstadosTelefono.MARCANDO) {
			centralita.liberarLineaNoUsada(this);
		} else if (estado==EstadosTelefono.RECEPTOR_OCUPADO) {
			centralita.liberarLineaNoUsada(this);
		} else if (estado==EstadosTelefono.NUMERO_INEXISTENTE) {
			centralita.colgadoSimple(this);
		} else if (estado==EstadosTelefono.ESPERANDO_RESPUESTA) {
			centralita.liberarLineaNoUsada(this);
		} else if (estado==EstadosTelefono.NO_HAY_LINEA) {
			centralita.liberarLineaNoUsada(this);
		} else if (estado==EstadosTelefono.CONVERSANDO) {
			centralita.finalizarConversacionEmisor(this);
		}
		setEstado(EstadosTelefono.EN_SILENCIO);
	}
	
	public void timbre() {
		setEstado(EstadosTelefono.TIMBRE_SONANDO);
	}

	private void setEstado(int estado) {
		this.estado=estado;	
		if (gui!=null)
			gui.updateState(estado);
	}

	public String getNumero() {
		return this.numero;
	}

	public int getEstado() {
		return this.estado;
	}

	public void setGui(JPTelefono gui) {
		this.gui=gui;
	}

	public void habilitarConversacionComoReceptor() {
		this.setEstado(EstadosTelefono.DESCOLGADO_RECEPTOR);
	}
}
