package tests;

import junit.framework.TestCase;
import dominio.Centralita;
import dominio.EstadosTelefono;
import dominio.Telefono;

public class TestCentralita extends TestCase {

	private Centralita centralita;
	private Telefono[] telefonos;

	protected void setUp() throws Exception {
		this.centralita=new Centralita(null);
		this.telefonos=new Telefono[25];
		int cont=0;
		for (int i=0; i<5; i++) {
			for (int j=0; j<5; j++) {
				Telefono t=new Telefono(this.centralita, cont);
				this.telefonos[cont]=t;
				this.centralita.add(t);
				cont++;
				t.setGui(null);
			}
		}
	}

	public void test1() {
		for (int i=0; i<this.telefonos.length; i++) {
			Telefono t=telefonos[i];
			assertTrue(t.getEstado()==EstadosTelefono.EN_SILENCIO);
		}
	}
	
	public void test2() {
		Telefono emisor=telefonos[0];
		emisor.descolgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.MARCANDO);
		emisor.marcar(1);
		assertTrue(emisor.getEstado()==EstadosTelefono.NUMERO_INEXISTENTE);
		emisor.colgar();
		emisor.descolgar();
		emisor.marcar(0); emisor.marcar(0); emisor.marcar(1);
		assertTrue(emisor.getEstado()==EstadosTelefono.ESPERANDO_RESPUESTA);
		Telefono receptor=telefonos[1];
		assertTrue(receptor.getEstado()==EstadosTelefono.TIMBRE_SONANDO);
		Telefono tercero=telefonos[2];
		tercero.descolgar();
		tercero.marcar(0); tercero.marcar(0); tercero.marcar(0);
		assertTrue(tercero.getEstado()==EstadosTelefono.RECEPTOR_OCUPADO);
		tercero.colgar();
		tercero.descolgar();
		tercero.marcar(0); tercero.marcar(0); tercero.marcar(1);
		assertTrue(tercero.getEstado()==EstadosTelefono.RECEPTOR_OCUPADO);
		tercero.colgar();
		receptor.descolgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.CONVERSANDO);
		assertTrue(receptor.getEstado()==EstadosTelefono.DESCOLGADO_RECEPTOR);
		emisor.colgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.EN_SILENCIO);
		assertTrue(receptor.getEstado()==EstadosTelefono.LLAMADA_TERMINADA);
	}
	
	public void test3() {
		Telefono emisor=telefonos[0];
		emisor.descolgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.MARCANDO);
		emisor.marcar(1);
		assertTrue(emisor.getEstado()==EstadosTelefono.NUMERO_INEXISTENTE);
		emisor.colgar();
		emisor.descolgar();
		emisor.marcar(0); emisor.marcar(0); emisor.marcar(1);
		assertTrue(emisor.getEstado()==EstadosTelefono.ESPERANDO_RESPUESTA);
		Telefono receptor=telefonos[1];
		assertTrue(receptor.getEstado()==EstadosTelefono.TIMBRE_SONANDO);
		Telefono tercero=telefonos[2];
		tercero.descolgar();
		tercero.marcar(0); tercero.marcar(0); tercero.marcar(0);
		assertTrue(tercero.getEstado()==EstadosTelefono.RECEPTOR_OCUPADO);
		tercero.colgar();
		tercero.descolgar();
		tercero.marcar(0); tercero.marcar(0); tercero.marcar(1);
		assertTrue(tercero.getEstado()==EstadosTelefono.RECEPTOR_OCUPADO);
		tercero.colgar();
		receptor.descolgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.CONVERSANDO);
		assertTrue(receptor.getEstado()==EstadosTelefono.DESCOLGADO_RECEPTOR);
		receptor.colgar();
		assertTrue(receptor.getEstado()==EstadosTelefono.EN_SILENCIO);
		assertTrue(emisor.getEstado()==EstadosTelefono.LLAMADA_TERMINADA);
	}
	
	public void test4() {
		Telefono emisor=telefonos[0];
		emisor.descolgar();
		emisor.marcar(0); emisor.marcar(0); 
		emisor.colgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.EN_SILENCIO);
	}
	
	public void test5() {
		Telefono emisor=telefonos[0];
		emisor.descolgar();
		emisor.marcar(0); emisor.marcar(0); emisor.marcar(1);
		emisor.colgar();
		assertTrue(emisor.getEstado()==EstadosTelefono.EN_SILENCIO);
	}
	
	public void test6() {
		telefonos[0].descolgar();
		telefonos[1].descolgar();
		telefonos[2].descolgar();
		telefonos[3].descolgar();
		telefonos[4].descolgar();
		telefonos[5].descolgar();
	}
	
	public void test7() {
		telefonos[0].descolgar();
		long timeIni=System.currentTimeMillis();
		while (System.currentTimeMillis()-timeIni<15000) ;
		System.out.println(EstadosTelefono.getMensaje(telefonos[0].getEstado()));
	}
}
